                <div class="card" style="min-height: 450px;">
                  <?php $i_ser = 0; ?>
                  <?php if(isset($data_hoteles)): ?>
                      <?php $url = route('hotel.single',$key->url).$data_hoteles['url']; ?>
                    <?php else: ?>
                      <?php $url = route('hotel.single',$key->url)?>
                    <?php endif; ?>
                  <?php if($key->imagenes->count() == 0): ?> 
                    <a href="<?php echo e($url); ?>">
                      <img class="card-img-top" src="<?php echo e(asset('img/hotel.png')); ?>" alt="Hotel" style="min-width: 150px !important; max-height: 150px !important;" />
                    </a>                    
                  <?php else: ?>
                    <a href="<?php echo e($url); ?>">
                      <img class="card-img-top" src="<?php echo e(asset($key->imagenes[0]->img)); ?>" alt="Hotel" style="min-width: 150px !important; max-height: 150px !important;" />
                    </a>                    
                  <?php endif; ?>                
                  <div class="card-body">
                    <a href="<?php echo e(route('hotel.single',$key->url)); ?>"><h6><?php echo e($key->nombre); ?></h6></a>
                    <?php if($key->servicios_principales_count() != 0): ?>
                      <small>Servicios </small>
                      <div data-flickity='{ "cellAlign": "center", "contain": true, "pageDots":true, "wrapAround":true, "autoPlay":false, "imagesLoaded":true, "groupCells": true,"groupCells": 3,"freeScroll": true}'> 
                        <?php $i_ser = 1; $i=0; ?>
                              <?php 
                              $ser_cant = $key->servicios_principales_count();
                              if ($ser_cant >= 5) {
                                $cant=2;
                              }else{
                                $cant =  12 / $ser_cant;
                              } 
                              $data = $key->servicios_principales();
                          ?>      

                          <?php for($i=0; $i<($ser_cant*2); $i++): ?>
                            <div class="col-<?php echo e($cant); ?>" style="padding: 0px;">
                                <img style="display: inline-block;" class="material-icons" 
                                src="<?php echo e(asset($data[$i])); ?>" data-toggle="tooltip" data-placement="top" 
                                <?php $i++; ?>
                                title="<?php echo e($data[$i]); ?>">
                              </div>
                          <?php endfor; ?>
                      </div>
                    <?php endif; ?>
                    <div class="mb-1 mt-4">
                      <div>
                        <h5>
                          <small>
                            Desde
                            <strong>
                              <?php if(session('id_moneda')==2): ?> Q <?php endif; ?>
                              <?php if(session('id_moneda')==1): ?> $ <?php endif; ?>
                            </strong>
                            <strong><?php echo e($key->precio_desde(session('id_moneda'))); ?> </strong>
                          </small>
                        </h5>
                        <div>

                          <?php for($e=0;$e<$key->estrellas;$e++): ?>
                            <i class="material-icons text-warning" style="display: inline-block;">star</i>
                          <?php endfor; ?>                       
                        
                          <div class="bg-dark text-white" style="min-width: 50px; max-width: 50px; float: right; border-radius: 5px;">
                            <center><?php echo e($key->promedio()); ?></center>
                          </div>
                        </div>
                        <?php if($key->recomendaciones->count() != 0): ?>
                          <strong>recomendado por:</strong><br>
                            <div class="row">
                              <?php $__currentLoopData = $key->recomendaciones; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $key2): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                              <div class="col">
                                <img src="<?php echo e(asset($key2->empresa->logo)); ?>" width="100px" height="40px">
                              </div>
                              <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>                         
                            </div>
                        <?php endif; ?>  

                        <?php if(isset($data_hoteles)): ?>
                          <br>
                          <?php if($key->check_disponibilidades($data_hoteles) == 'OK'): ?>
                            <small class="text-success mb-1 mt-2">Hay habitaciones disponibles para la fecha indicada </small>                             
                          <?php else: ?>
                            <small class="text-danger mb-1 mt-2"><?php echo e($key->check_disponibilidades($data_hoteles)); ?></small>       
                          <?php endif; ?> 
                        <?php endif; ?>              
                      </div>
                    </div>
                  </div>
                  <div class="card-footer">
                    <div class="d-flex align-items-center justify-content-between">
                        <?php if(isset($data_hoteles)): ?>
                          <a href="<?php echo e(route('hotel.single',$key->url)); ?><?php echo e($data_hoteles['url']); ?>">Ver más</a>
                        <?php else: ?>
                          <a href="<?php echo e(route('hotel.single',$key->url)); ?>">Ver más</a>
                        <?php endif; ?>                         
                        <i class="material-icons text-dark">keyboard_arrow_right</i>
                    </div>
                  </div>
                </div><?php /**PATH C:\xampp\htdocs\guatehoteles\resources\views/layouts/cardhoteles.blade.php ENDPATH**/ ?>